@@ -6,17 +6,17 @@
 
 require_relative '../../../lib/async/container/controller'
 
-# Console.logger.debug!
+$stdout.sync = true
 
 class Dots < Async::Container::Controller
 	def setup(container)
 		container.run(name: "dots", count: 1, restart: true) do |instance|
 			instance.ready!
 			
-			sleep 1
+			# This is to avoid race conditions in the controller in test conditions.
+			sleep 0.1
 			
 			$stdout.write "."
-			$stdout.flush
 			
 			sleep
 		rescue Async::Container::Interrupt
